(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     21288,        618]*)
(*NotebookOutlinePosition[     22039,        644]*)
(*  CellTagsIndexPosition[     21995,        640]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Introduction to ",
    FontSize->14],
  StyleBox["Mathematica.",
    FontSize->14,
    FontSlant->"Italic"],
  StyleBox[" Volume I - Mathematics",
    FontSize->14],
  "\n",
  StyleBox["download this document from ",
    FontWeight->"Plain"],
  StyleBox["www.hakenberg.de",
    FontFamily->"Courier New",
    FontWeight->"Plain"]
}], "Subsubsection"],

Cell[TextData[{
  "\[WarningSign] Please ",
  StyleBox["deactivate NUM-Lock",
    FontWeight->"Bold"],
  ".\n\[WarningSign] Proceed by copying the expressions into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Press \[ShiftKey]\[ReturnKey] together to ",
  StyleBox["evaluate",
    FontWeight->"Bold"],
  " the expressions. ",
  "Vary the input. ",
  "\n\[WarningSign] When you recieve weird error messages upon evaluation, \
although your input seems correct, use the menu item \n",
  StyleBox["Kernel",
    FontWeight->"Bold"],
  " \[ShortRightArrow] ",
  StyleBox["Quit-Kernel",
    FontWeight->"Bold"],
  " to reset the memory of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and start evaluation from the beginning. "
}], "Text"],

Cell[TextData[{
  "First, we perform ",
  "a",
  " ",
  StyleBox["derivation",
    FontWeight->"Bold"],
  ", define the ",
  StyleBox["value",
    FontWeight->"Bold"],
  " of a ",
  StyleBox["variable",
    FontWeight->"Bold"],
  ", a ",
  StyleBox["list",
    FontWeight->"Bold"],
  " and a ",
  StyleBox["mathematical",
    FontWeight->"Bold"],
  " ",
  StyleBox["function",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f : \[DoubleStruckCapitalR]\^2 \[Rule] \
\[DoubleStruckCapitalR]\^3\)]],
  ".\n\[LightBulb] use \[ControlKey]2, \[ControlKey]-, \[ControlKey]^  to \
create expressions as ",
  Cell[BoxData[
      \(TraditionalForm\`\@2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`4\^10\)]],
  "  (alternatively use the icons on the palettes at the side) \n\[LightBulb] \
for greek letters \[Pi], \[Alpha], etc. use sequences like \[EscapeKey]pi\
\[EscapeKey], \[EscapeKey]a\[EscapeKey]\t\t\[LightBulb] the imaginary unit is \
\[EscapeKey]ii\[EscapeKey] "
}], "Text"],

Cell[BoxData[{
    \(12 + \@6 - D[Sin[x]\ x\^3, {x, 2}]\), "\[IndentingNewLine]", 
    \(myVar = \(47!\)\), "\[IndentingNewLine]", 
    \(myList = {7, Sin[\[Pi]/3], \(-\@23\), 4\^10, a, x\_1, 
        2 + 4  \[ImaginaryI], {2, 99}}\), "\[IndentingNewLine]", 
    \(myF[x\_1, 
        x\_2] = {\((R + r\ \ Cos[x\_2])\)\ Cos[
            x\_1], \((R + r\ \ Cos[x\_2])\)\ Sin[x\_1], 
        r\ \ Sin[x\_2]}\), "\[IndentingNewLine]", 
    \(myEqs = \(\(3 + x - 
          4  x\^3\)\(\[Equal]\)\(0\)\(\ \ \ \ \ \ \ \ \ \ \)\( (*\[ShiftKey]\
\[ReturnKey]*) \)\(\ \)\)\)}], "Input"],

Cell[TextData[{
  "Upon ",
  StyleBox["evaluation",
    FontWeight->"Bold"],
  ", the definitions are ",
  StyleBox["memorized",
    FontWeight->"Bold"],
  " by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". We work with ",
  StyleBox["myVar",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["myList",
    FontFamily->"Courier New"],
  ", etc. in the sequel. We ",
  StyleBox["solve",
    FontWeight->"Bold"],
  " for unknowns, convert to ",
  StyleBox["numerical",
    FontWeight->"Bold"],
  " values and ",
  StyleBox["substitute",
    FontWeight->"Bold"],
  " a coordinate into the function. \n\[LightBulb] ",
  StyleBox["Re",
    FontFamily->"Courier New"],
  " gives the real part of a complex number \t\[LightBulb] the right arrow \
\[Rule] is dumped upon the combination \[EscapeKey]",
  StyleBox["->",
    FontFamily->"Courier New"],
  "\[EscapeKey] \n\[LightBulb] the appearence of /. reminds us of the \
\[Lambda] in \[Lambda]-calculus, /. represents a substitution "
}], "Text"],

Cell[BoxData[{
    \(N[myList]\), "\[IndentingNewLine]", 
    \(myF[x\_1, x\_2] /. {x\_1 \[Rule] 44}\), "\[IndentingNewLine]", 
    \(mySol = Solve[myEqs, {x}]\), "\[IndentingNewLine]", 
    \(Re[x] /. mySol\)}], "Input"],

Cell[TextData[{
  "Explicit math: ",
  StyleBox["Sums",
    FontWeight->"Bold"],
  ", ",
  StyleBox["integrals",
    FontWeight->"Bold"],
  ", ",
  StyleBox["derivatives",
    FontWeight->"Bold"],
  ", ",
  StyleBox["limits",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Taylor",
    FontWeight->"Bold"],
  "-expansion.\n\[LightBulb] for \[Infinity] use the sequence \[EscapeKey]inf\
\[EscapeKey] "
}], "Text"],

Cell[BoxData[{
    \({\[Sum]\+\(k = 1\)\%n k\^2, \[Sum]\+\(k = 1\)\%\[Infinity] k\^\(-8\), \
\[Integral]Cosh[t] \[DifferentialD]t, \[Integral]\_0\%\[Infinity] 
            Exp[\(-\[Lambda]\)\ \ t] \[DifferentialD]t}\), "\
\[IndentingNewLine]", 
    \(\[PartialD]\_\(x\_2\)\ myF[x\_1, x\_2]\), "\[IndentingNewLine]", 
    \(Limit[myVar\ Sin[x]/x, x \[Rule] 0]\), "\[IndentingNewLine]", 
    \(Series[Cosh[x], {x, 0, 8}]\)}], "Input"],

Cell[TextData[{
  "Lets produce some ",
  StyleBox["graphics",
    FontWeight->"Bold"],
  ". \[Wolf] Why do we substitute values for ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " in the third example? "
}], "Text"],

Cell[BoxData[{
    \(Plot[{Sin[3\ t], t\^2, Cosh[t], 4 - t}, {t, 0, 
        2}]\), "\[IndentingNewLine]", 
    \(Plot3D[
      Abs[Gamma[x + \[ImaginaryI]\ \ y]], {x, \(-5\), 3}, {y, \(-1\), 1}, 
      PlotPoints \[Rule] 50]\), "\[IndentingNewLine]", 
    \(ParametricPlot[{t\ Cos[2\ t], t\ Sin[t]}, {t, 0, 
        2  \[Pi]}]\), "\[IndentingNewLine]", 
    \(ParametricPlot3D[
      Evaluate[myF[x\_1, x\_2] /. {R \[Rule] 2, r \[Rule] 1}], {x\_1, 0, 
        2\ \[Pi] - 1.5}, {x\_2, 0, 2  \[Pi] - 1}]\), "\[IndentingNewLine]", 
    \(ContourPlot[
      Cos[x\ \ y], {x, \(-5\), 5}, {y, \(-5\), 5}, {PlotPoints \[Rule] 30, 
        ContourLines \[Rule] False}]\)}], "Input"],

Cell[TextData[{
  "Implicit math: ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  " systems of ",
  StyleBox["non linear equations",
    FontWeight->"Bold"],
  ", ",
  StyleBox["differential equations",
    FontWeight->"Bold"],
  ",",
  StyleBox[" ",
    FontWeight->"Bold"],
  "and",
  StyleBox[" simplification",
    FontWeight->"Bold"],
  ".",
  "\n\[Wolf] activate the help browser with \[ShiftKey]F1 and look up \
commands like ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(mySol = 
      Solve[{y\^2 \[Equal] x\^3 - x + 1, 
          2\ y \[Equal] \(-3\)\ x}]\), "\[IndentingNewLine]", 
    \(MatrixForm[N[mySol]]\)}], "Input"],

Cell[BoxData[{
    \(Eliminate[{x \[Equal] 3\ y\^2 + b, 
        y\ x \[Equal] b}, {y}]\), "\[IndentingNewLine]", 
    \({Solve[{1/a \[Equal] 1/c}, {a}], 
      Reduce[{1/a \[Equal] 1/c}, {a}]}\), "\[IndentingNewLine]", 
    \(myY = 
      DSolve[{\(y\_1'\)[x] \[Equal] y\_1[x] + y\_2[x], \(y\_2'\)[x] \[Equal] 
            x\ Sin[x] + 3\ y\_1[x], y\_1[0] \[Equal] \[Alpha]}, {y\_1[x], 
          y\_2[x]}, x]\), "\[IndentingNewLine]", 
    \(FullSimplify[myY]\), "\[IndentingNewLine]", 
    \(Simplify[
      Log[a\ b] \[Equal] 
        Log[a] + Log[b], {0 < a < b}]\), "\[IndentingNewLine]", 
    \(ListPlot[\({Re[x], Im[x]} /. #1 &\) /@ 
        NSolve[{x\^25 + 7\ x\^21 - 3\ x\^12 + 7\ x\^11 + 4\ x\^8 - 
                10\ x\^5 \[Equal] 1}, {x}]]\)}], "Input"],

Cell[TextData[{
  "Various functions concerning ",
  StyleBox["numbers ",
    FontWeight->"Bold"],
  "and ",
  StyleBox["polynomials",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(N[\[Pi], 80]\), "\[IndentingNewLine]", 
    \(\(BernoulliB[#1] &\) /@ Range[18]\), "\[IndentingNewLine]", 
    \(FactorInteger[
      Prime[1000]\^2\ \ Prime[2000]\ \ Prime[
          3000]]\), "\[IndentingNewLine]", 
    \(LegendreP[4, x]\), "\[IndentingNewLine]", 
    \(PolynomialGCD[\(\((1 - x)\)\^2\) \(\((1 + x)\)\^2\) \((2 + x)\), \((1 - 
            x)\) \((2 + x)\) \((3 + x)\)]\)}], "Input"],

Cell[TextData[{
  "Basics in ",
  StyleBox["linear algebra",
    FontWeight->"Bold"],
  "; determinant, inverse, matrix/vector multiplication, eigensystem.\n\
\[LightBulb] to enter a matrix, place your cursor between two round brackets, \
like this: ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[VerticalEllipsis])\)\)]],
  ", then ...\n\[Bullet] keep hitting \[ControlKey]\[EnterKey] to add rows    \
     \[Bullet] keep hitting \[ControlKey]",
  StyleBox[",",
    FontSize->16],
  " to add columns.\nUse the \[TabKey] key to toggle between the empty spots \
\[Square]"
}], "Text"],

Cell[BoxData[{
    RowBox[{"myM", "=", 
      RowBox[{"(", GridBox[{
            {"a", "b"},
            {"c", "0"}
            }], ")"}]}], "\[IndentingNewLine]", \(myM . {d, 
        e}\), "\[IndentingNewLine]", \({d, e} . 
      myM\), "\[IndentingNewLine]", \(myI = 
      Inverse[myM]\), "\[IndentingNewLine]", \(MF = 
      MatrixForm\), "\[IndentingNewLine]", \(myI // 
      MF\), "\[IndentingNewLine]", \(myI . {d, e} - 
      LinearSolve[myM, {d, e}]\), "\[IndentingNewLine]", \(\(#1 + #2\ x &\)[
      6, 7]\), "\[IndentingNewLine]", \(myB = 
      Array[#1\ \((#2 + a\ \ #1)\) &, {3, 
          3}]\), "\[IndentingNewLine]", \(myB // 
      MF\), "\[IndentingNewLine]", \(Eigenvalues[
      myB]\), "\[IndentingNewLine]", \(Eigenvectors[
      myB]\), "\[IndentingNewLine]", 
    RowBox[{"NullSpace", "[", 
      RowBox[{"(", GridBox[{
            {"1", "0", \(-1\), "0", "0"},
            {"0", "0", "0", "1", "0"}
            }], ")"}], 
      "]"}], "\[IndentingNewLine]", \(FullSimplify[MatrixExp[myM]] // 
      MF\)}], "Input"],

Cell[TextData[{
  "From ",
  StyleBox["logic: boolean expressions",
    FontWeight->"Bold"],
  ", non-commutative multiplication.\n\[LightBulb] Type \[EscapeKey]=>\
\[EscapeKey] for \[DoubleRightArrow]"
}], "Text"],

Cell[BoxData[{
    \(LogicalExpand[\(! \((a || \(! \((b && \(! c\))\)\) && \(! \((d || \(! d\
\))\)\))\)\)]\), "\[IndentingNewLine]", 
    \(\(! \((a && b)\)\) \[Implies] \(! a\) || \(! b\) // 
      LogicalExpand\), "\[IndentingNewLine]", 
    \(And @@ {0 < 1, b, True, a, a \[Equal] b}\), "\[IndentingNewLine]", 
    \({a\ b \[Equal] b\ a, a ** b \[Equal] b ** a}\)}], "Input"],

Cell[TextData[{
  StyleBox["Finite fields",
    FontWeight->"Bold"],
  " of order ",
  Cell[BoxData[
      \(TraditionalForm\`p\^n\)]],
  ", multiplication of polynomials is defined by a certain irreducible \
polynomial. For the purpose of demonstration, we pick ",
  Cell[BoxData[
      \(TraditionalForm\`p = 5\)]],
  " prime and ",
  Cell[BoxData[
      \(TraditionalForm\`n = 4\)]],
  ". Elements are adressed by integer coefficients of polynomials."
}], "Text"],

Cell[BoxData[{
    \(<< Algebra`FiniteFields`\), "\[IndentingNewLine]", 
    \(myF = GF[5, 4]\), "\[IndentingNewLine]", 
    \(elem = myF[{1, 2}] + myF[{2, 2, 2, 1}]\), "\[IndentingNewLine]", 
    \(ElementToPolynomial[elem, x]\), "\[IndentingNewLine]", 
    \(\(GF[5, 4]\)[{1, 2, 1}]\ \(GF[5, 4]\)[{2, 2, 2, 
          1}]\), "\[IndentingNewLine]", 
    \(FieldIrreducible[GF[5, 4], x]\)}], "Input"],

Cell[TextData[{
  StyleBox["Tensors",
    FontWeight->"Bold"],
  " are essential in geometry. The following code yields to a given metric ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptG]\_\(i, j\)\)]],
  " the Christoffel-Tensor ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_\(i, j\)\%k\)]],
  " and the Riemannian curvature tensor ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR]\_\(i, j, k\)\%l\)]],
  ", all expressions depending on coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1,  ... , x\_n\)]],
  ". The ",
  StyleBox["Dot",
    FontFamily->"Courier New"],
  " operation for matrices extends to ",
  "tensors",
  " of arbitrary rank."
}], "Text"],

Cell[BoxData[{
    \(T = Transpose\), "\[IndentingNewLine]", 
    \(\[CapitalMu]d[X_, r_] := 
      T[Array[D[X, x\_#1] &, {Length[X]}], 
        Flatten[{r + 1, Range[r]}]]\), "\[IndentingNewLine]", 
    \(\[CapitalMu]\[CapitalGamma][\[ScriptG]_] := 
      Inverse[\[ScriptG]] . 
          With[{Q = \[CapitalMu]d[\[ScriptG], 0]}, \(-Q\) + T[Q, {2, 3, 1}] + 
              T[Q, {3, 1, 2}]]/2\), "\[IndentingNewLine]", 
    \(\[CapitalMu]\[ScriptCapitalR][\[ScriptG]_] := 
      T[\[CapitalMu]d[\[CapitalMu]\[CapitalGamma][\[ScriptG]], 
              1] + \[CapitalMu]\[CapitalGamma][\[ScriptG]] . \[CapitalMu]\
\[CapitalGamma][\[ScriptG]], {1, 4, 3, 2}] - 
        T[\[CapitalMu]d[\[CapitalMu]\[CapitalGamma][\[ScriptG]], 
              1] + \[CapitalMu]\[CapitalGamma][\[ScriptG]] . \[CapitalMu]\
\[CapitalGamma][\[ScriptG]], {1, 3, 4, 2}]\)}], "Input"],

Cell[TextData[{
  "\[LightBulb] For illustration we use the induced metric of ",
  Cell[BoxData[
      \(TraditionalForm\`S\^2 \[Subset] \[DoubleStruckCapitalR]\^3\)]],
  " with radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ". We can show that the sectional curvature is constant."
}], "Text"],

Cell[BoxData[{
    RowBox[{"\[ScriptG]", "=", 
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\(r\^2\ Cos[x\_2]\^2\), "0"},
              {"0", \(r\^2\)}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ 
          BoxForm`e$]]]}], "\[IndentingNewLine]", \(\[ScriptCapitalR] = 
      FullSimplify[\[CapitalMu]\[ScriptCapitalR][\[ScriptG]]]\), "\
\[IndentingNewLine]", \(X = {x\_1, 
        x\_2}\), "\[IndentingNewLine]", \(Y = {y\_1, 
        y\_2}\), "\[IndentingNewLine]", \(FullSimplify[\((\[ScriptG] . \
\[ScriptCapitalR] . X . Y . X . 
            Y)\)/\((\((\[ScriptG] . X . X)\)\ \((\[ScriptG] . Y . 
                  Y)\) - \((\[ScriptG] . X . Y)\)\^2)\)]\)}], "Input"],

Cell["\<\
Formal setup and treatment of tensors.
\[LightBulb] Produce \[LeftDoubleBracket] by \[EscapeKey][[\[EscapeKey], \
analogous \[RightDoubleBracket]\
\>", "Text"],

Cell[BoxData[{
    \(dim = Dimensions\), "\[IndentingNewLine]", 
    \(myC = Array[c\_\(#1, #2, #3\) &, {2, 3, 4}]\), "\[IndentingNewLine]", 
    \(myD = 
      Array[D[x\^5, {x, #1}] + #2 + Sin[#4] &, {4, 5, 2, 
          2}]\), "\[IndentingNewLine]", 
    \(dim[myC]\), "\[IndentingNewLine]", 
    \(dim[Transpose[myC, {3, 2, 1}]]\), "\[IndentingNewLine]", 
    \(dim[myC . myD]\), "\[IndentingNewLine]", 
    \(dim[Transpose[myC, {2, 3, 1}]]\), "\[IndentingNewLine]", 
    \(myC\[LeftDoubleBracket]2, All, 
      3\[RightDoubleBracket]\), "\[IndentingNewLine]", 
    \(myC\[LeftDoubleBracket]1, {3, 2}\[RightDoubleBracket] = 
      myC\[LeftDoubleBracket]1, {2, 1}\[RightDoubleBracket]\)}], "Input"],

Cell[TextData[{
  "Some ",
  StyleBox["differential equations",
    FontWeight->"Bold"],
  " require ",
  StyleBox["numerical treatment",
    FontWeight->"Bold"],
  ". We also teach the use of ",
  StyleBox["InterpolationFunction",
    FontFamily->"Courier New"],
  ".\n\[Wolf] the equations below describe geodesics on the geometric torus \
with radiuses ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  "."
}], "Text"],

Cell[BoxData[{
    RowBox[{"geod", "=", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    SubsuperscriptBox["x", "1", "\[Prime]\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
                  FractionBox[
                    RowBox[{"2", " ", "r", " ", \(Sin[x\_2[t]]\), " ", 
                      RowBox[{
                        SubsuperscriptBox["x", "1", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SubsuperscriptBox["x", "2", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], \(R + 
                      r\ Cos[x\_2[t]]\)]}], ",", 
                RowBox[{
                  RowBox[{
                    SubsuperscriptBox["x", "1", "\[Prime]",
                      MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                  ".1"}], ",", \(x\_1[0] \[Equal]  .2\), ",", 
                "\[IndentingNewLine]", 
                RowBox[{
                  RowBox[{
                    SubsuperscriptBox["x", "2", "\[Prime]\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
                  
                  RowBox[{\(-\((R + r\ Cos[x\_2[t]])\)\), 
                    " ", \(Sin[x\_2[t]]\), " ", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{
                          SubsuperscriptBox["x", "1", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"], 
                      "/", "r"}]}]}], ",", 
                RowBox[{
                  RowBox[{
                    SubsuperscriptBox["x", "2", "\[Prime]",
                      MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                  "1"}], ",", \(x\_2[0] \[Equal]  .3\)}], "}"}], ",", 
            "\[IndentingNewLine]", \({x\_1[t], x\_2[t]}\), 
            ",", \({t, \(-10\), 10}\)}], "}"}], 
        "/.", \({R \[Rule] 2, 
          r \[Rule] 1.1}\)}]}], "\[IndentingNewLine]", \(sol = 
      NDSolve @@ geod\), "\[IndentingNewLine]", \(sol /. 
      t \[Rule] 3.4\), "\[IndentingNewLine]", 
    RowBox[{\(Off[ParametricPlot::"\<ppcom\>"];\), 
      " ", \( (*no\ message\ when\ compilation\ to\ plot\ failed*) \)}], "\
\[IndentingNewLine]", \(ParametricPlot[{x\_1[t], x\_2[t]} /. 
          sol\[LeftDoubleBracket]1\[RightDoubleBracket], {t, \(-10\), 
          10}];\)}], "Input"],

Cell[TextData[{
  "Some expressions do not translate to an explicit form, but ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " might still know rules, how to manipulate certain entities. This results \
in",
  StyleBox[" implicit descriptions",
    FontWeight->"Bold"],
  " via functions like ",
  StyleBox["Polygamma",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["ProductLog",
    FontFamily->"Courier New"],
  ", etc."
}], "Text"],

Cell[BoxData[{
    \(D[\(x!\), x]\), "\[IndentingNewLine]", 
    \(Integrate[Exp[\(-t\^2\)], t]\), "\[IndentingNewLine]", 
    \(Reduce[z \[Equal] w\ Exp[w], w]\), "\[IndentingNewLine]", 
    \(SphericalHarmonicY[3, 2, \[Theta], \[Phi]]\), "\[IndentingNewLine]", 
    \(DSolve[b\ \(x'\)[t] \[Equal] a\ t\^\[Alpha] + x[t]\^2, x[t], 
      t]\), "\[IndentingNewLine]", 
    \(myRec = 
      y[x] /. \(RSolve[{y[x + 2] \[Equal] 2\ x\ y[x + 1] + y[x], 
              y[0] \[Equal] 1, y[1] == 1}, y[x], 
            x]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\), "\
\[IndentingNewLine]", 
    \(Plot3D[
      Abs[myRec /. x \[Rule] r + s\ \[ImaginaryI]], {r, \(-2\), 
        5}, {s, \(-2\), 5}, ViewPoint \[Rule] {\(-1\), 1, 1}]\)}], "Input"],

Cell[TextData[{
  "Convolution of ",
  StyleBox["piecewise continuous functions ",
    FontWeight->"Bold"],
  "(",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " lacks elegance on this topic)"
}], "Text"],

Cell[BoxData[{
    \(bas1 = UnitStep[x + 1/2] - UnitStep[x - 1/2]\), "\[IndentingNewLine]", 
    \(\(Plot[bas1, {x, \(-2\), 2}];\)\), "\[IndentingNewLine]", 
    \(bas2 = \[Integral]\_\(-\[Infinity]\)\%\[Infinity] 
            bas1\ \((bas1 /. x \[Rule] x - s)\)\ \[DifferentialD]x // 
        FullSimplify\), "\[IndentingNewLine]", 
    \(\(Plot[bas2, {s, \(-2\), 2}];\)\)}], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 957}},
WindowSize->{910, 927},
WindowMargins->{{56, Automatic}, {-20, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowCellLabel->False,
Magnification->1.25
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 378, 14, 57, "Subsubsection"],
Cell[2157, 69, 761, 23, 104, "Text"],
Cell[2921, 94, 1068, 39, 82, "Text"],
Cell[3992, 135, 576, 11, 130, "Input"],
Cell[4571, 148, 1005, 34, 103, "Text"],
Cell[5579, 184, 221, 4, 98, "Input"],
Cell[5803, 190, 410, 18, 60, "Text"],
Cell[6216, 210, 432, 7, 130, "Input"],
Cell[6651, 219, 282, 11, 39, "Text"],
Cell[6936, 232, 675, 13, 120, "Input"],
Cell[7614, 247, 509, 22, 60, "Text"],
Cell[8126, 271, 175, 4, 57, "Input"],
Cell[8304, 277, 766, 15, 163, "Input"],
Cell[9073, 294, 177, 8, 39, "Text"],
Cell[9253, 304, 422, 8, 121, "Input"],
Cell[9678, 314, 585, 15, 107, "Text"],
Cell[10266, 331, 1045, 24, 339, "Input"],
Cell[11314, 357, 214, 6, 60, "Text"],
Cell[11531, 365, 379, 6, 98, "Input"],
Cell[11913, 373, 466, 14, 60, "Text"],
Cell[12382, 389, 400, 7, 140, "Input"],
Cell[12785, 398, 700, 21, 82, "Text"],
Cell[13488, 421, 855, 15, 119, "Input"],
Cell[14346, 438, 307, 8, 38, "Text"],
Cell[14656, 448, 845, 19, 142, "Input"],
Cell[15504, 469, 169, 4, 59, "Text"],
Cell[15676, 475, 702, 13, 204, "Input"],
Cell[16381, 490, 483, 18, 60, "Text"],
Cell[16867, 510, 2606, 54, 186, "Input"],
Cell[19476, 566, 448, 15, 60, "Text"],
Cell[19927, 583, 741, 14, 163, "Input"],
Cell[20671, 599, 213, 8, 39, "Text"],
Cell[20887, 609, 385, 6, 118, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

