(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14332,        443]*)
(*NotebookOutlinePosition[     15103,        470]*)
(*  CellTagsIndexPosition[     15059,        466]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Introduction to ",
    FontSize->14],
  StyleBox["Mathematica.",
    FontSize->14,
    FontSlant->"Italic"],
  StyleBox[" Volume II - Programming",
    FontSize->14],
  "\n",
  StyleBox["download this document from ",
    FontWeight->"Plain"],
  StyleBox["www.hakenberg.de",
    FontFamily->"Courier New",
    FontWeight->"Plain"]
}], "Subsubsection"],

Cell[TextData[{
  "\[WarningSign] Please ",
  StyleBox["deactivate NUM-Lock",
    FontWeight->"Bold"],
  ".\n\[WarningSign] Proceed by copying the expressions into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Press \[ShiftKey]\[ReturnKey] together to ",
  StyleBox["evaluate",
    FontWeight->"Bold"],
  " the expressions. ",
  "Vary the input. ",
  "\n\[WarningSign] When you recieve weird error messages upon evaluation, \
although your input seems correct, use the menu item \n",
  StyleBox["Kernel",
    FontWeight->"Bold"],
  " \[ShortRightArrow] ",
  StyleBox["Quit-Kernel",
    FontWeight->"Bold"],
  " to reset the memory of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and start evaluation from the beginning. "
}], "Text"],

Cell[TextData[{
  "Difference between ",
  Cell[BoxData[
      \(TraditionalForm\` := \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\` = \)]]
}], "Text"],

Cell[BoxData[{
    \(rnd1 = Random[]\), "\[IndentingNewLine]", 
    \(rnd2 := Random[]\), "\[IndentingNewLine]", 
    \({rnd1, rnd1, rnd2, rnd2}\)}], "Input"],

Cell[TextData[{
  "Various ways to ",
  "define ",
  StyleBox["functions",
    FontWeight->"Bold"],
  " and to ",
  StyleBox["call",
    FontWeight->"Bold"],
  " them with arguments",
  "\n\[LightBulb] ",
  Cell[BoxData[
      \(TraditionalForm\`y_List\)]],
  " requires the second argument to be a list. ",
  Cell[BoxData[
      \(TraditionalForm\`z_:  \[ImaginaryI]\)]],
  " indicates, that the third argument ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " is optional and the default value is ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\)]],
  " in this particular case. Produce \[CircleTimes] with \[EscapeKey]c*\
\[EscapeKey]"
}], "Text"],

Cell[BoxData[{
    \(myF1[x_, y_List, z_:  \[ImaginaryI]] := 
      y\^x + z\), "\[IndentingNewLine]", 
    \(myF2 = #2\^#1 + #3 &\), "\[IndentingNewLine]", 
    \(X_\[CircleTimes]Y_ := Outer[Times, X, Y]\)}], "Input"],

Cell[BoxData[{
    \(myF1[3, a]\), "\[IndentingNewLine]", 
    \(myF1[3, {a, b}]\), "\[IndentingNewLine]", 
    \(myF2[3, a, \[ImaginaryI]]\), "\[IndentingNewLine]", 
    \({1, 2, 3}\[CircleTimes]{a, b, c, d} // MatrixForm\)}], "Input"],

Cell[BoxData[
    \(\(a\_##1 &\)[4, x, \[Pi]]\)], "Input"],

Cell[TextData[{
  "Instead of using \"",
  Cell[BoxData[
      \(TraditionalForm\`\([ ... ]\)\)]],
  "\" for function-calls, alternative notation prooves to be extremly useful.\
\n\[Wolf] when you are familiar to the syntax below, set ",
  StyleBox["myF",
    FontFamily->"Courier New"],
  " equal to functions like ",
  StyleBox["Sin",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["Plus",
    FontFamily->"Courier New"],
  ", etc."
}], "Text"],

Cell[BoxData[{
    \(hisF@\(yourF@\(myF@3. \)\)\), "\[IndentingNewLine]", 
    \({1, 2, 3. } // myF\), "\[IndentingNewLine]", 
    \(myF @@ {1, 2, 3. }\), "\[IndentingNewLine]", 
    \(myF /@ {1, 2, 3. }\), "\[IndentingNewLine]", 
    \(myF //@ {1, 2, 3. }\), "\[IndentingNewLine]", 
    \(Nest[myF, x, 6]\)}], "Input"],

Cell[BoxData[{
    \(DSolve @@ {{\(y'\)[x] \[Equal] y[x] + x, 
          y[0] \[Equal] \[Alpha]}, {y[x]}, x}\), "\[IndentingNewLine]", 
    \(\(#1 + Cosh[#2\^#3] &\) @@ {x, y, z}\)}], "Input"],

Cell[TextData[{
  "The following code implements the formula that alternates/skews a given \
tensor of arbitrary rank. Let ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  " be a tensor of rank ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " on say ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^n\)]],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  " consists of ",
  Cell[BoxData[
      \(TraditionalForm\`n\^r\)]],
  " entries addressed by ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\(i\_1,  ... , i\_r\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`i\_j \[Element] {1,  ... , n}\)]],
  ". With ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalS]\_r\)]],
  " as the group of permutations of ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " elements, the alternate tensor of ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  " is defined \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalA](X)\)\_\(i\_1,  ... , i\_r\) = \
\(1\/\(r!\)\) \(\[Sum]\_\(\[Sigma] \[Element] \[ScriptCapitalS]\_r\)\(sign(\
\[Sigma])\)\[CenterDot]X\_\(\[Sigma](i\_1,  ... , i\_r)\)\)\)]],
  "\nNote, how the different functional operators are combined below to \
produce a compact appearance.\n\[LightBulb] \[ScriptCapitalA] corresponds to \
\[EscapeKey]scA\[EscapeKey], in which \"sc\" stands for ",
  StyleBox["sc",
    FontSlant->"Italic"],
  StyleBox["ript",
    FontSlant->"Italic"],
  ". Try also \[EscapeKey]goA\[EscapeKey]."
}], "Text"],

Cell[BoxData[{\(rank = 
      TensorRank\), "\[IndentingNewLine]", \(\[ScriptCapitalA][X_] := 
      1/\(rank[X]!\)\ Plus @@ \((\(Signature[#1]\ Transpose[X, #1] &\) /@ 
              Permutations[Range[rank[X]]])\)\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalA]", "[", 
        RowBox[{"(", GridBox[{
              {"x", "4"},
              {"\[Pi]", "y"}
              }], ")"}], "]"}], "//", "MatrixForm"}]}], "Input"],

Cell[TextData[{
  "The following functions help to ",
  StyleBox["circumvent while/for",
    FontWeight->"Bold"],
  " loops. \n\[WarningSign] read about ",
  StyleBox["FixedPoint",
    FontFamily->"Courier New"],
  " before you modify the code below. "
}], "Text"],

Cell[BoxData[{
    \(Fold[myF, a0, {a1, a2, a3}]\), "\[IndentingNewLine]", 
    \(FoldList[myF, a0, {a1, a2, a3}]\), "\[IndentingNewLine]", 
    \(NestList[Min[5, #1 + Random[]] &, 0, 6]\), "\[IndentingNewLine]", 
    \(FixedPointList[Min[5, #1 + Random[]] &, 0]\), "\[IndentingNewLine]", 
    \(FixedPoint[Min[5, #1 + Random[]] &, 0]\)}], "Input"],

Cell[TextData[{
  StyleBox["Memo functions",
    FontWeight->"Bold"],
  " help you to increase efficiency. The code below defines a recursive \
computation of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " factorial, i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`\(n!\)\)]],
  ". ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " creates a lookup table for all input parameters that ",
  StyleBox["fac",
    FontFamily->"Courier New"],
  " has seen so far."
}], "Text"],

Cell[BoxData[{
    \(\(fac[0] = 1;\)\), "\[IndentingNewLine]", 
    \(\(fac[n_] := \(fac[n] = n\ fac[n - 1]\);\)\), "\[IndentingNewLine]", 
    \(fac[5]\), "\[IndentingNewLine]", 
    \(\(?fac\)\)}], "Input"],

Cell[TextData[{
  StyleBox["If",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Which",
    FontFamily->"Courier New"],
  " are classical commands to ",
  StyleBox["control the flow ",
    FontWeight->"Bold"],
  "of the ",
  "program",
  ".\n\[LightBulb] for \[NotEqual] just type ",
  StyleBox["!=",
    FontFamily->"Courier New"],
  " \t\t\[Wolf] try different values for ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " in the last line "
}], "Text"],

Cell[BoxData[{
    \(\(If[#1 \[NotEqual] 0, 1/#1, \[Infinity]] &\) /@ {1, 1/2, 3, 
        0}\), "\[IndentingNewLine]", 
    \("\<we\>" // 
      Which[#1 \[Equal] "\<I\>", "\<am\>", #1 \[Equal] "\<he\>", "\<is\>", 
          True, "\<are\>"] &\), "\[IndentingNewLine]", 
    \(n = 4; 
    While[Mod[n, 5] \[NotEqual] 1, n = Mod[n\^3 - 2\ n + 1, 11]; 
      Print[n]]\)}], "Input"],

Cell[TextData[{
  "Get familiar to some useful functions that ",
  StyleBox["manipulate lists",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(myList = {a1, {a2, a3}, a4, {{a5}, a6}};\)\), "\[IndentingNewLine]", 
    \(Length[myList]\), "\[IndentingNewLine]", 
    \(Flatten[myList]\), "\[IndentingNewLine]", 
    \(Reverse[myList]\), "\[IndentingNewLine]", 
    \(Drop[myList, 1]\), "\[IndentingNewLine]", 
    \(Range[4, 10]\), "\[IndentingNewLine]", 
    \(Select[{20, 2, x, 4, \[Pi], 10}, #1 > \[Pi] &]\)}], "Input"],

Cell[TextData[{
  "A",
  StyleBox[" Module",
    FontWeight->"Bold"],
  " is the most general form of a function/procedure in ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "and only useful, when a lot of decisions and repetitions are required. The \
code below controls, i.e. accelerates, a particle on a line from initial \
state ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(vel\_0\),
              FontWeight->"Bold"], ",", \(pos\_0 = 0\)}], ")"}], 
        TraditionalForm]]],
  " to the target state ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(vel\_T\),
              FontWeight->"Bold"], ",", 
            StyleBox[\(pos\_T\),
              FontWeight->"Bold"]}], ")"}], TraditionalForm]]],
  ". The bold variables are input parameters to the program. Acceleration is \
bounded and the control is ",
  StyleBox["time optimal",
    FontSlant->"Italic"],
  ". The particle is subject to friction. For higher dimensions this problem \
is hard!\n\[Wolf] The algorithm as shown could be stable, however, if ",
  StyleBox["vel=0",
    FontFamily->"Courier New"],
  " there are difficulties in computing ",
  StyleBox["est",
    FontFamily->"Courier New"],
  ", which is easily traced back to the computation of ",
  StyleBox["sgn",
    FontFamily->"Courier New"],
  " one line above. Lookup the definition of ",
  StyleBox["Sign",
    FontFamily->"Courier New"],
  " and make a minor change to the algorithm by treating the case ",
  StyleBox["vel=0",
    FontFamily->"Courier New"],
  " differently. Launch the new code with ",
  StyleBox["move[0,-1,.5]",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(move[vel0_, posT_, velT_] := 
        Module[{cnt, states = {}, pos = 0, vel = vel0, tmp, \[Tau] =  .01, 
            est}, \[IndentingNewLine]For[cnt = 0, 
            cnt < 1500, \(cnt++\); \[IndentingNewLine]sgn = 
              Sign[\(-vel\)]; \[IndentingNewLine]est = 
              vel - velT + 
                sgn\ Log[\((sgn - vel)\)/\((sgn - 
                          velT)\)]; \[IndentingNewLine]acc = 
              If[pos + est < posT, 1, \(-1\)]; \[IndentingNewLine]AppendTo[
              states, {vel += acc\ \[Tau] - vel\ \[Tau], 
                pos += vel\ \[Tau]}]\[IndentingNewLine]]; \
\[IndentingNewLine]ListPlot[states, AxesLabel \[Rule] "\<Phase\>", 
            PlotRange \[Rule] 
              All];\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(move[\(- .7\), 1, \(- .4\)]\)}], "Input"],

Cell[TextData[{
  "Functions like ",
  StyleBox["Sin",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Exp",
    FontFamily->"Courier New"],
  " have the ",
  StyleBox["attribute",
    FontWeight->"Bold"],
  " ",
  StyleBox["Listable",
    FontFamily->"Courier New"],
  ", see example below. Check out the attribute ",
  StyleBox["Orderless",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(SetAttributes[myZ, {Listable}]\), "\[IndentingNewLine]", 
    \(myZ[{1, {2, 3}, 4}]\)}], "Input"],

Cell[TextData[{
  "\[Wolf] We close with an example for students familiar to lie algebras: \
The following lines lists all possible commutator tables of three dimensional \
lie algebras. For certain choices of coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i, j, k\)\)]],
  " they are necessarily isomorphic. The symbol \[FivePointedStar] dumps upon \
\[EscapeKey]*5\[EscapeKey]. "
}], "Text"],

Cell[BoxData[{
    \(\(ad\[FivePointedStar][n_] := 
        Array[Which[#2 > #3, 
              a\_\(#1, #2, #3\), #2 < #3, \(-a\_\(#1, #3, #2\)\), True, 
              0] &, {n, n, n}];\)\), "\[IndentingNewLine]", 
    \(\(adJacobi[ad_] := 
        Plus @@ \((\(Transpose[ad . ad, #1] &\) /@ {{1, 2, 3, 4}, {1, 3, 4, 
                  2}, {1, 4, 2, 3}})\);\)\), "\[IndentingNewLine]", 
    \(\(ShowAd[ad_] := 
        MatrixForm[
          Array[e\_#1 &, {Length[
                  ad]}] . \(-ad\)];\)\), "\[IndentingNewLine]", 
    \(\(ShowAd[Simplify[ad\[FivePointedStar][3] /. #1]] &\) /@ 
      Solve[\(0 \[Equal] #1 &\) /@ 
          Flatten[adJacobi[ad\[FivePointedStar][3]]]]\)}], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 957}},
WindowSize->{882, 927},
WindowMargins->{{Automatic, 37}, {-5, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowSelection->True,
ShowCellLabel->False,
Magnification->1.25
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 379, 14, 57, "Subsubsection"],
Cell[2158, 69, 761, 23, 104, "Text"],
Cell[2922, 94, 163, 7, 38, "Text"],
Cell[3088, 103, 158, 3, 77, "Input"],
Cell[3249, 108, 665, 23, 81, "Text"],
Cell[3917, 133, 218, 4, 79, "Input"],
Cell[4138, 139, 236, 4, 98, "Input"],
Cell[4377, 145, 58, 1, 35, "Input"],
Cell[4438, 148, 450, 15, 59, "Text"],
Cell[4891, 165, 319, 6, 140, "Input"],
Cell[5213, 173, 192, 3, 58, "Input"],
Cell[5408, 178, 1524, 45, 147, "Text"],
Cell[6935, 225, 447, 9, 113, "Input"],
Cell[7385, 236, 264, 8, 60, "Text"],
Cell[7652, 246, 348, 5, 119, "Input"],
Cell[8003, 253, 489, 17, 60, "Text"],
Cell[8495, 272, 208, 4, 98, "Input"],
Cell[8706, 278, 467, 18, 60, "Text"],
Cell[9176, 298, 381, 8, 78, "Input"],
Cell[9560, 308, 139, 5, 39, "Text"],
Cell[9702, 315, 400, 7, 161, "Input"],
Cell[10105, 324, 1724, 50, 165, "Text"],
Cell[11832, 376, 848, 15, 245, "Input"],
Cell[12683, 393, 400, 17, 39, "Text"],
Cell[13086, 412, 118, 2, 56, "Input"],
Cell[13207, 416, 408, 8, 80, "Text"],
Cell[13618, 426, 698, 14, 99, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

