(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8422,        278]*)
(*NotebookOutlinePosition[      9172,        304]*)
(*  CellTagsIndexPosition[      9128,        300]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Introduction to ",
    FontSize->14],
  StyleBox["Mathematica.",
    FontSize->14,
    FontSlant->"Italic"],
  StyleBox[" Volume III - XtraStuff",
    FontSize->14],
  "\n",
  StyleBox["download this document from ",
    FontWeight->"Plain"],
  StyleBox["www.hakenberg.de",
    FontFamily->"Courier New",
    FontWeight->"Plain"]
}], "Subsubsection"],

Cell[TextData[{
  "\[WarningSign] Please ",
  StyleBox["deactivate NUM-Lock",
    FontWeight->"Bold"],
  ".\n\[WarningSign] Proceed by copying the expressions into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Press \[ShiftKey]\[ReturnKey] together to ",
  StyleBox["evaluate",
    FontWeight->"Bold"],
  " your input. Vary the input. \n\[WarningSign] When you recieve weird error \
messages upon evaluation, although your input seems correct, use the menu \
item \n",
  StyleBox["Kernel",
    FontWeight->"Bold"],
  " \[ShortRightArrow] ",
  StyleBox["Quit-Kernel",
    FontWeight->"Bold"],
  " to reset the memory of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and start evaluation from the beginning. "
}], "Text"],

Cell[TextData[{
  "\[Wolf] Understand the function ",
  StyleBox["\[Gamma]Init",
    FontFamily->"Courier New"],
  " "
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(\[Gamma]Init[n_Int]\)[X0_]\), ":=", 
        RowBox[{"MapIndexed", "[", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{
                  
                  SubsuperscriptBox[
                    "x", \(#2\[LeftDoubleBracket]1\[RightDoubleBracket]\), 
                    TagBox[\((n)\),
                      Derivative],
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                "#1"}], "&"}], ",", "X0"}], "]"}]}], ";"}]], "Input"],

Cell[TextData[{
  "\[Wolf] Evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " at 1/2 and plot the function within an appropriate interval, where "
}], "Text"],

Cell[BoxData[
    \(f = Interpolation[{{0, 2}, {1, \(-1\)}, {3, 1}, {5, 6}}]\)], "Input"],

Cell[TextData[{
  "\[Wolf] Describe the difference between ",
  StyleBox["NestList",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["FixedPointList",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  "\[Wolf] Think about how to setup a general matrix in arbitrary dimension \
",
  Cell[BoxData[
      \(TraditionalForm\`n\[Cross]n\)]],
  " such as "
}], "Text"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(a\_1\), \(a\_2\), \(a\_3\), \(a\_4\)},
            {\(a\_2\), \(a\_5\), \(a\_6\), \(a\_7\)},
            {\(a\_3\), \(a\_6\), \(a\_8\), \(a\_9\)},
            {\(a\_4\), \(a\_7\), \(a\_9\), \(a\_10\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Input"],

Cell[TextData[{
  "\[Wolf] Our presentation of legal syntax in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is far from complete. That does not automatically mean, you can't live \
without them. But if brevity and efficiency appeals to you, we point you to \
",
  StyleBox["Programming ",
    FontWeight->"Bold"],
  "\[ShortRightArrow]",
  StyleBox[" Assignments",
    FontWeight->"Bold"],
  " in the help browser. You find things such as"
}], "Text"],

Cell[BoxData[{
    \(\(Unprotect[Sin];\)\), "\[IndentingNewLine]", 
    \(\(Sin /: Sin[x_] Cos[y_] := Sin[x + y]/2 + Sin[x - y]/2;\)\)}], "Input"],

Cell[TextData[{
  "\[Wolf] Imagine a graph with vertices ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_1, v\_2, v\_3}\)]],
  " and directed edges ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1 \[Rule] v\_2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2 \[Rule] v\_3\)]],
  ". We encode the connectivity by the matrix ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " below. The entry of the matrix product ",
  Cell[BoxData[
      \(TraditionalForm\`\((A . A)\)\_\(i, j\)\)]],
  " corresponds to the number of paths of length 2 going from ",
  Cell[BoxData[
      \(TraditionalForm\`v\_j \[Rule] v\_i\)]],
  ". In our example ",
  Cell[BoxData[
      \(TraditionalForm\`\((A . A)\)\_\(3, 1\) = 1\)]],
  ", because the only path connecting ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_3\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1 \[Rule] \(v\_2 \[Rule] v\_3\)\)]],
  ". Design code, that outputs the connectivity relation table ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(i, j\) \[Element] {0, 1}\^\(n\[Cross]n\)\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(i, j\) = 1\)]],
  " \[DoubleLeftRightArrow] \[Exists] a directed path from ",
  Cell[BoxData[
      \(TraditionalForm\`v\_j \[Rule] \(\(...\)\(\[Rule]\)\(v\_i\)\)\)]],
  ". "
}], "Text"],

Cell[BoxData[
    RowBox[{"A", "=", 
      RowBox[{"(", GridBox[{
            {"0", "0", "0"},
            {"1", "0", "0"},
            {"0", "1", "0"}
            }], ")"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solutions to some of the problems ", "Subsubsection"],

Cell[TextData[{
  StyleBox["f[1/2]",
    FontFamily->"Courier New"],
  " tells you that mathematica uses algebraic (polynomial) interpolation, \
when fed with non-numerical input. "
}], "Text"],

Cell[TextData[{
  "Concerning the general symmetric bilinear form, a ",
  StyleBox["Module",
    FontFamily->"Courier New"],
  " allows you to assign a single entry of a list (\[WarningSign] ",
  StyleBox["With",
    FontFamily->"Courier New"],
  " does not replace ",
  StyleBox["Module",
    FontFamily->"Courier New"],
  " here). We are not aware of a more elegant solution than: "
}], "Text"],

Cell[BoxData[
    \(\(Sym[n_] := 
        Module[{A = Array[0 &, {n, n}], 
            cnt = 0}, \[IndentingNewLine]Array[\((A\[LeftDoubleBracket]#1, #2\
\[RightDoubleBracket] = 
                  If[#1 \[LessEqual] #2, a\_\(++cnt\), 
                    A\[LeftDoubleBracket]#2, #1\[RightDoubleBracket]])\) &, \
{n, n}]];\)\)], "Input"],

Cell[TextData[{
  "The connectivity relation table is indeed the result of a fixed point \
routine. Try the below code with more exciting matrices ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and use the command ",
  StyleBox["FixedPoint",
    FontFamily->"Courier New"],
  " instead of ",
  StyleBox["FixedPointList",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(myMax[a_] := Min[a, 1];\)\), "\[IndentingNewLine]", 
    \(SetAttributes[myMax, Listable]\), "\[IndentingNewLine]", 
    \(FixedPointList[myMax[#1 + #1 . #1] &, A]\)}], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 957}},
WindowSize->{911, 900},
WindowMargins->{{Automatic, 24}, {Automatic, 14}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowCellLabel->False,
Magnification->1.25
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 378, 14, 57, "Subsubsection"],
Cell[2157, 69, 746, 22, 104, "Text"],
Cell[2906, 93, 130, 5, 38, "Text"],
Cell[3039, 100, 554, 14, 39, "Input"],
Cell[3596, 116, 171, 5, 38, "Text"],
Cell[3770, 123, 89, 1, 35, "Input"],
Cell[3862, 126, 206, 8, 38, "Text"],
Cell[4071, 136, 179, 6, 38, "Text"],
Cell[4253, 144, 357, 8, 85, "Input"],
Cell[4613, 154, 465, 13, 81, "Text"],
Cell[5081, 169, 146, 2, 56, "Input"],
Cell[5230, 173, 1372, 41, 101, "Text"],
Cell[6605, 216, 186, 6, 67, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6828, 227, 59, 0, 34, "Subsubsection"],
Cell[6890, 229, 193, 5, 38, "Text"],
Cell[7086, 236, 396, 11, 59, "Text"],
Cell[7485, 249, 337, 7, 56, "Input"],
Cell[7825, 258, 378, 12, 59, "Text"],
Cell[8206, 272, 200, 3, 77, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

